@@ -2,15 +2,15 @@
 ## Plotting the legend for a sequence object
 ## =========================================
 
-seqlegend <- function(seqdata, cpal, ltext, 
+seqlegend <- function(seqdata, cpal=NULL, ltext=NULL, 
 	position="topleft", fontsize=1,...) {
 	
 	if (!inherits(seqdata,"stslist"))
 		stop("data is not a sequence object, use seqdef function to create one")
 
-	if (missing(cpal)) cpal <- attr(seqdata,"cpal")
+	if (is.null(cpal)) cpal <- attr(seqdata,"cpal")
 
-	if (missing(ltext)) ltext <- attr(seqdata,"labels")
+	if (is.null(ltext)) ltext <- attr(seqdata,"labels")
 
 	plot(0, type= "n", axes=FALSE, xlab="", ylab="")
 	legend(position, fill=cpal, legend=ltext, cex=fontsize,...)
